@@ -3,12 +3,12 @@ use std::collections::VecDeque;
 
 pub fn solve(input: &mut Input) -> Result<u64, String> {
     // Indexed by days left mapping to number of fishes with that many days left:
-    let mut count_oer_day_left = VecDeque::from([0; 9]);
+    let mut count_per_day_left = VecDeque::from([0; 9]);
 
     for day_left_str in input.text.split(',') {
         match day_left_str.parse::<u8>() {
             Ok(day_left) if day_left <= 8 => {
-                count_oer_day_left[day_left as usize] += 1;
+                count_per_day_left[day_left as usize] += 1;
             }
             _ => {
                 return Err(
@@ -19,13 +19,13 @@ pub fn solve(input: &mut Input) -> Result<u64, String> {
     }
 
     for _day in 0..input.part_values(80, 256) {
-        count_oer_day_left.rotate_left(1);
-        // Those with 0 days left have given birth to new ones with 8 days left - but we need to
-        // add themselves back (reset to 6 days left):
-        count_oer_day_left[6] += count_oer_day_left[8];
+        count_per_day_left.rotate_left(1);
+        // Those with 0 days left have given birth to new ones with 8 days
+        // left - but we need to also add them back (reset to 6 days left):
+        count_per_day_left[6] += count_per_day_left[8];
     }
 
-    Ok(count_oer_day_left.iter().sum())
+    Ok(count_per_day_left.iter().sum())
 }
 
 #[test]
